"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

function _buildTools() {
  const data = require("@expo/build-tools");

  _buildTools = function () {
    return data;
  };

  return data;
}

function _config() {
  const data = require("@expo/config");

  _config = function () {
    return data;
  };

  return data;
}

function _xdl() {
  const data = require("@expo/xdl");

  _xdl = function () {
    return data;
  };

  return data;
}

function _log() {
  const data = _interopRequireDefault(require("../../log"));

  _log = function () {
    return data;
  };

  return data;
}

function _Builder() {
  const data = _interopRequireDefault(require("./Builder"));

  _Builder = function () {
    return data;
  };

  return data;
}

function _utils() {
  const data = require("./utils");

  _utils = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function buildAction(projectDir, {
  platform
}) {
  if (!platform || !Object.values(_buildTools().Platform).includes(platform)) {
    throw new Error('Pass valid platform: [android|ios]');
  }

  const ctx = await createBuilderContextAsync(projectDir);
  const builder = new (_Builder().default)(ctx);
  const buildArtifactUrl = await builder.buildProjectAsync(platform);
  (0, _log().default)(`Artifact url: ${buildArtifactUrl}`);
}

async function statusAction(projectDir) {
  const ctx = await createBuilderContextAsync(projectDir);
  const builder = new (_Builder().default)(ctx);
  const result = await builder.getLatestBuildsAsync();
  (0, _utils().printBuildTable)(result.builds);
}

async function createBuilderContextAsync(projectDir) {
  const user = await _xdl().UserManager.ensureLoggedInAsync();
  const {
    exp
  } = (0, _config().getConfig)(projectDir);
  const accountName = exp.owner || user.username;
  const projectName = exp.slug;
  return {
    projectDir,
    user,
    accountName,
    projectName,
    exp
  };
}

function _default(program) {
  program.command('build [project-dir]').description('Build an app binary for your project, signed and ready for submission to the Google Play Store / App Store.').option('-p --platform <platform>', 'Platform: [android|ios]', /^(android|ios)$/i).asyncActionProjectDir(buildAction, {
    checkConfig: true
  });
  program.command('build:status').description(`Get the status of the latest builds for your project.`).asyncActionProjectDir(statusAction, {
    checkConfig: true
  });
}
//# sourceMappingURL=index.js.map