import { Context, IView } from '../context';
import { IosAppCredentials, IosPushCredentials } from '../credentials';
import { CredentialSchema } from '../actions/promptForCredentials';
import { PushKey } from '../../appleApi';
declare type CliOptions = {
    nonInteractive?: boolean;
};
export declare type PushKeyOptions = {
    experienceName: string;
    bundleIdentifier: string;
} & CliOptions;
export declare class CreateIosPush implements IView {
    _nonInteractive: boolean;
    constructor(options?: CliOptions);
    create(ctx: Context): Promise<IosPushCredentials>;
    open(ctx: Context): Promise<IView | null>;
    _getRequiredQuestions(ctx: Context): CredentialSchema<PushKey>;
    _ensurePushKey(ctx: Context, partialKey: Partial<PushKey>): PushKey;
    provideOrGenerate(ctx: Context): Promise<PushKey>;
}
export declare class RemoveIosPush implements IView {
    shouldRevoke: boolean;
    nonInteractive: boolean;
    constructor(shouldRevoke?: boolean, nonInteractive?: boolean);
    open(ctx: Context): Promise<IView | null>;
    removePushCert(ctx: Context, appCredentials: IosAppCredentials): Promise<void>;
    removeSpecific(ctx: Context, selected: IosPushCredentials): Promise<void>;
}
export declare class UpdateIosPush implements IView {
    open(ctx: Context): Promise<null>;
    updateSpecific(ctx: Context, selected: IosPushCredentials): Promise<void>;
    provideOrGenerate(ctx: Context): Promise<PushKey>;
}
export declare class UseExistingPushNotification implements IView {
    _experienceName: string;
    _bundleIdentifier: string;
    constructor(options: PushKeyOptions);
    static withProjectContext(ctx: Context): UseExistingPushNotification | null;
    open(ctx: Context): Promise<IView | null>;
}
export declare class CreateOrReusePushKey implements IView {
    _experienceName: string;
    _bundleIdentifier: string;
    _nonInteractive: boolean;
    constructor(options: PushKeyOptions);
    assignPushKey(ctx: Context, userCredentialsId: number): Promise<void>;
    open(ctx: Context): Promise<IView | null>;
    _createOrReuse(ctx: Context): Promise<IView | null>;
}
export declare function validatePushKey(ctx: Context, pushKey: PushKey): Promise<boolean>;
export declare function getPushKeyFromParams(builderOptions: {
    pushId?: string;
    pushP8Path?: string;
    teamId?: string;
}): Promise<PushKey | null>;
export declare function usePushKeyFromParams(ctx: Context, appCredentials: IosAppCredentials, pushKey: PushKey): Promise<IosPushCredentials>;
export {};
